aboutsummaryrefslogtreecommitdiff
path: root/lib/service/servicedvb.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'lib/service/servicedvb.cpp')
-rw-r--r--lib/service/servicedvb.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/lib/service/servicedvb.cpp b/lib/service/servicedvb.cpp
index cd4d3394..0da33635 100644
--- a/lib/service/servicedvb.cpp
+++ b/lib/service/servicedvb.cpp
@@ -1220,8 +1220,8 @@ RESULT eDVBServicePlay::stop()
{
int perc = play_position * 100LL / length;
- /* only store last play position when between 5% and 95% */
- if ((5 < perc) && (perc < 95))
+ /* only store last play position when between 1% and 99% */
+ if ((1 < perc) && (perc < 99))
m_cue_entries.insert(cueEntry(play_position, 3)); /* last play position */
}
m_cuesheet_changed = 1;